"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = require("fs");

var _bcrypt = _interopRequireDefault(require("bcrypt"));

var _user = require("../../models/user");

var _database = require("../../submodules/database");

var _argumentError = _interopRequireDefault(require("./helpers/argumentError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = async args => {
  const sequelize = (0, _database.initDatabase)();
  let config = JSON.parse(await _fs.promises.readFile('/etc/oblecto/config.json'));

  if (args.length < 5) {
    (0, _argumentError.default)('adduser', ['username', 'password', 'realname', 'email']);
    return;
  }

  let hash = await _bcrypt.default.hash(args[2], config.authentication.saltRounds);
  let [user, inserted] = await _user.User.findOrCreate({
    where: {
      username: args[1]
    },
    defaults: {
      name: args[3],
      email: args[4],
      password: hash
    }
  });

  if (inserted) {
    console.log('User has been created');
  } else {
    console.log('A user that with username already exists!');
  }

  sequelize.close();
};

exports.default = _default;