"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _uuid = require("uuid");

var _fs = require("fs");

var _nodeRsa = _interopRequireDefault(require("node-rsa"));

var _generateAssetDirectories = _interopRequireDefault(require("../helpers/generateAssetDirectories"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = async args => {
  let config = JSON.parse(await _fs.promises.readFile(__dirname + '/../../../../res/config.json'));

  try {
    await _fs.promises.mkdir('/etc/oblecto');
  } catch (e) {
    if (e.code !== 'EEXIST') {
      console.log('Unable to create Oblecto data directory. Aborting');
      console.log('Please create the directory "/etc/oblecto" and give current user read/write permissions');
      return;
    }
  }

  (0, _generateAssetDirectories.default)(config);
  config.authentication.secret = (0, _uuid.v4)();
  console.log('Generating federation UUID');
  config.federation.uuid = (0, _uuid.v4)();
  console.log('Creating config file');

  try {
    await _fs.promises.writeFile('/etc/oblecto/config.json', JSON.stringify(config, null, 4));
  } catch (e) {
    console.log(e);
  }

  console.log('Generating federation authentication keys');
  const key = new _nodeRsa.default({
    b: 2048
  });
  await _fs.promises.writeFile('/etc/oblecto/id_rsa', key.exportKey('pkcs1-private-pem'));
  await _fs.promises.writeFile('/etc/oblecto/id_rsa.pub', key.exportKey('pkcs1-public-pem'));
  console.log('Federation TLS keys will need to be generated manually');
  console.log('Please refer to the Oblecto wiki for instructions');
  console.log('https://github.com/robinp7720/Oblecto/wiki/Federation');
};

exports.default = _default;