"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _WarnExtendableError = _interopRequireDefault(require("../../errors/WarnExtendableError"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

var _downloader = _interopRequireDefault(require("../../downloader"));

var _DebugExtendableError = _interopRequireDefault(require("../../errors/DebugExtendableError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AggregateMovieArtworkRetriever {
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.retrievers = [];
  }

  loadRetriever(retriever) {
    this.retrievers.push(retriever);
  }

  async retrieveFanart(movie) {
    for (let retriever of this.retrievers) {
      try {
        let urls = await retriever.retrieveFanart(movie);
        if (urls.length === 0) throw new _DebugExtendableError.default('No URLs found');
        return _downloader.default.attemptDownload(urls, this.oblecto.artworkUtils.movieFanartPath(movie));
      } catch (e) {
        _logger.default.log(e);
      }
    }

    throw new _WarnExtendableError.default(`No fanart found for movie ${movie.movieName}`);
  }

  async retrievePoster(movie) {
    for (let retriever of this.retrievers) {
      try {
        let urls = await retriever.retrievePoster(movie);
        if (urls.length === 0) throw new _DebugExtendableError.default('No URLs found');
        return _downloader.default.attemptDownload(urls, this.oblecto.artworkUtils.moviePosterPath(movie));
      } catch (e) {
        _logger.default.log(e);
      }
    }

    throw new _WarnExtendableError.default(`No poster found for movie ${movie.movieName}`);
  }

}

exports.default = AggregateMovieArtworkRetriever;