"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _downloader = _interopRequireDefault(require("../../downloader"));

var _TmdbMovieArtworkRetriever = _interopRequireDefault(require("./artworkRetrievers/TmdbMovieArtworkRetriever"));

var _FanarttvMovieArtworkRetriever = _interopRequireDefault(require("./artworkRetrievers/FanarttvMovieArtworkRetriever"));

var _AggregateMovieArtworkRetriever = _interopRequireDefault(require("./AggregateMovieArtworkRetriever"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class MovieArtworkDownloader {
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.movieArtworkRetriever = new _AggregateMovieArtworkRetriever.default(this.oblecto);
    this.movieArtworkRetriever.loadRetriever(new _FanarttvMovieArtworkRetriever.default(this.oblecto));
    this.movieArtworkRetriever.loadRetriever(new _TmdbMovieArtworkRetriever.default(this.oblecto)); // Register task availability to Oblecto queue

    this.oblecto.queue.registerJob('downloadMoviePoster', async job => {
      await this.downloadMoviePoster(job);
    });
    this.oblecto.queue.registerJob('downloadMovieFanart', async job => {
      await this.downloadMovieFanart(job);
    });
  }

  async downloadMoviePoster(movie) {
    await this.movieArtworkRetriever.retrievePoster(movie);

    _logger.default.log('DEBUG', `Poster for ${movie.movieName} downloaded`);

    for (let size of Object.keys(this.oblecto.config.artwork.poster)) {
      this.oblecto.queue.pushJob('rescaleImage', {
        from: this.oblecto.artworkUtils.moviePosterPath(movie),
        to: this.oblecto.artworkUtils.moviePosterPath(movie, size),
        width: this.oblecto.config.artwork.poster[size]
      });
    }
  }

  async downloadMovieFanart(movie) {
    await this.movieArtworkRetriever.retrieveFanart(movie);

    _logger.default.log('DEBUG', `Fanart for ${movie.movieName} downloaded`);

    for (let size of Object.keys(this.oblecto.config.artwork.fanart)) {
      this.oblecto.queue.pushJob('rescaleImage', {
        from: this.oblecto.artworkUtils.movieFanartPath(movie),
        to: this.oblecto.artworkUtils.movieFanartPath(movie, size),
        width: this.oblecto.config.artwork.fanart[size]
      });
    }
  }

}

exports.default = MovieArtworkDownloader;