"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _WarnExtendableError = _interopRequireDefault(require("../../errors/WarnExtendableError"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

var _DebugExtendableError = _interopRequireDefault(require("../../errors/DebugExtendableError"));

var _downloader = _interopRequireDefault(require("../../downloader"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AggregateSeriesArtworkRetriever {
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.retrievers = [];
  }

  loadRetriever(retriever) {
    this.retrievers.push(retriever);
  }

  async retrieveEpisodeBanner(episode) {
    for (let retriever of this.retrievers) {
      try {
        let urls = await retriever.retrieveEpisodeBanner(episode);
        if (urls.length === 0) throw new _DebugExtendableError.default('No URLs found');
        return _downloader.default.attemptDownload(urls, this.oblecto.artworkUtils.episodeBannerPath(episode));
      } catch (e) {
        _logger.default.log(e);
      }
    }

    throw new _WarnExtendableError.default(`No banner found for episode ${episode.episodeName}`);
  }

  async retrieveSeriesPoster(series) {
    for (let retriever of this.retrievers) {
      try {
        let urls = await retriever.retrieveSeriesPoster(series);
        if (urls.length === 0) throw new _DebugExtendableError.default('No URLs found');
        return _downloader.default.attemptDownload(urls, this.oblecto.artworkUtils.seriesPosterPath(series));
      } catch (e) {
        _logger.default.log(e);
      }
    }

    throw new _WarnExtendableError.default(`No poster found for ${series.seriesName}`);
  }

}

exports.default = AggregateSeriesArtworkRetriever;