"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = require("fs");

var _episode = require("../../../models/episode");

var _series = require("../../../models/series");

class SeriesArtworkCollector {
  /**
   *
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
  }
  /**
   *
   * @param {Episode} episode - Episode for which to download the episode banner for
   * @returns {Promise<void>}
   */


  async collectArtworkEpisodeBanner(episode) {
    let stat;

    try {
      stat = await _fs.promises.stat(this.oblecto.artworkUtils.episodeBannerPath(episode));
    } catch (e) {}

    if (stat) return;
    this.oblecto.queue.queueJob('downloadEpisodeBanner', episode);
  }
  /**
   *
   * @param {Series} series - Series for which to download the series poster for
   * @returns {Promise<void>}
   */


  async collectArtworkSeriesPoster(series) {
    let stat;

    try {
      stat = await _fs.promises.stat(this.oblecto.artworkUtils.seriesPosterPath(series));
    } catch (e) {}

    if (stat) return;
    this.oblecto.queue.queueJob('downloadSeriesPoster', series);
  }
  /**
   *
   * @returns {Promise<void>}
   */


  async collectAllEpisodeBanners() {
    let episodes = await _episode.Episode.findAll();

    for (let episode of episodes) {
      await this.collectArtworkEpisodeBanner(episode);
    }
  }
  /**
   *
   * @returns {Promise<void>}
   */


  async collectAllSeriesPosters() {
    let allSeries = await _series.Series.findAll();

    for (let series of allSeries) {
      await this.collectArtworkSeriesPoster(series);
    }
  }
  /**
   *
   * @returns {Promise<void>}
   */


  async collectAll() {
    await this.collectAllSeriesPosters();
    await this.collectAllEpisodeBanners();
  }

}

exports.default = SeriesArtworkCollector;