"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _AggregateSeriesArtworkRetriever = _interopRequireDefault(require("./AggregateSeriesArtworkRetriever"));

var _TmdbSeriesArtworkRetriever = _interopRequireDefault(require("./artworkRetrievers/TmdbSeriesArtworkRetriever"));

var _TvdbSeriesArtworkRetriever = _interopRequireDefault(require("./artworkRetrievers/TvdbSeriesArtworkRetriever"));

var _FanarttvSeriesArtworkRetriever = _interopRequireDefault(require("./artworkRetrievers/FanarttvSeriesArtworkRetriever"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class SeriesArtworkDownloader {
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.seriesArtworkRetriever = new _AggregateSeriesArtworkRetriever.default(this.oblecto);
    this.seriesArtworkRetriever.loadRetriever(new _TmdbSeriesArtworkRetriever.default(this.oblecto));
    this.seriesArtworkRetriever.loadRetriever(new _FanarttvSeriesArtworkRetriever.default(this.oblecto));
    this.seriesArtworkRetriever.loadRetriever(new _TvdbSeriesArtworkRetriever.default(this.oblecto)); // Register task availability to Oblecto queue

    this.oblecto.queue.registerJob('downloadEpisodeBanner', this.downloadEpisodeBanner);
    this.oblecto.queue.registerJob('downloadSeriesPoster', this.downloadSeriesPoster);
  }

  async downloadEpisodeBanner(episode) {
    await this.seriesArtworkRetriever.retrieveEpisodeBanner(episode);

    _logger.default.log('DEBUG', `Banner for ${episode.episodeName} downloaded`);

    for (let size of Object.keys(this.oblecto.config.artwork.banner)) {
      this.oblecto.queue.pushJob('rescaleImage', {
        from: this.oblecto.artworkUtils.episodeBannerPath(episode),
        to: this.oblecto.artworkUtils.episodeBannerPath(episode, size),
        width: this.oblecto.config.artwork.banner[size]
      });
    }
  }

  async downloadSeriesPoster(series) {
    await this.seriesArtworkRetriever.retrieveSeriesPoster(series);

    _logger.default.log('DEBUG', `Poster for ${series.seriesName} downloaded`);

    for (let size of Object.keys(this.oblecto.config.artwork.poster)) {
      this.oblecto.queue.pushJob('rescaleImage', {
        from: this.oblecto.artworkUtils.seriesPosterPath(series),
        to: this.oblecto.artworkUtils.seriesPosterPath(series, size),
        width: this.oblecto.config.artwork.poster[size]
      });
    }
  }

}

exports.default = SeriesArtworkDownloader;