"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _episode = require("../../models/episode");

var _file = require("../../models/file");

var _series = require("../../models/series");

var _logger = _interopRequireDefault(require("../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class SeriesCleaner {
  /**
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
  }
  /**
   * Remove all episodes from the database without any linked files
   *
   * @returns {Promise<void>}
   */


  async removeFileLessEpisodes() {
    _logger.default.log('INFO', 'Removing all episodes without linked files');

    let results = await _episode.Episode.findAll({
      include: [_file.File]
    });

    for (let item of results) {
      if (item.Files && item.Files.length > 0) continue;

      _logger.default.log('INFO', 'Removing', item.episodeName, 'as it has no linked files');

      await item.destroy();
    }
  }
  /**
   * Remove all shows from the database without any defined path
   *
   * @returns {Promise<void>}
   */


  async removePathLessShows() {
    _logger.default.log('INFO', 'Removing series without at attached path');

    await _series.Series.destroy({
      where: {
        directory: ''
      }
    });
  }
  /**
   * Remove all shows from the database without any linked episodes
   *
   * @returns {Promise<void>}
   */


  async removeEpisodeslessShows() {
    _logger.default.log('INFO', 'Removing series without attached episodes');

    let results = await _series.Series.findAll({
      include: [_episode.Episode]
    });

    for (let item of results) {
      if (item.Episodes && item.Episodes.length > 0) continue;

      _logger.default.log('INFO', 'Removing', item.seriesName, 'as it has no linked episodes');

      await item.destroy();
    }
  }

}

exports.default = SeriesCleaner;