"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _IdentificationError = _interopRequireDefault(require("../errors/IdentificationError"));

var _logger = _interopRequireDefault(require("../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AggregateIdentifier {
  /**
   * Wrapper class to combine multiple identifiers and return information as a combined json output
   */
  constructor() {
    this.identifiers = [];
  }
  /**
   *
   * @param {MediaIdentifier} identifier
   */


  loadIdentifier(identifier) {
    this.identifiers.push(identifier);
  }

  async identify(...args) {
    let identification = {};

    for (let identifier of this.identifiers) {
      let currentIdentification;

      try {
        currentIdentification = await identifier.identify(...args);
      } catch (e) {
        _logger.default.log(e);

        continue;
      }

      identification = { ...identification,
        ...currentIdentification
      };
    }

    if (Object.keys(identification).length === 0) throw new _IdentificationError.default(`Could not identify: ${args[0]}`);
    return identification;
  }

}

exports.default = AggregateIdentifier;
;