"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _logger = _interopRequireDefault(require("../../submodules/logger"));

var _IdentificationError = _interopRequireDefault(require("../errors/IdentificationError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AggregateUpdateRetriever {
  /**
   * Wrapper class to combine multiple entity updaters and return information as a combined json output
   */
  constructor() {
    this.retrievers = [];
  }

  loadRetriever(retriever) {
    this.retrievers.push(retriever);
  }

  async retrieveInformation(...args) {
    let information = {};

    for (let retriever of this.retrievers) {
      try {
        let currentInformation = await retriever.retrieveInformation(...args);
        information = { ...information,
          ...currentInformation
        };
      } catch (e) {
        _logger.default.log(e);
      }
    }

    if (Object.keys(information).length === 0) throw new _IdentificationError.default('No identification match could be found');
    return information;
  }

}

exports.default = AggregateUpdateRetriever;