"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = require("fs");

var _axiosTimeout = _interopRequireDefault(require("../../submodules/axiosTimeout"));

var _logger = _interopRequireDefault(require("../../submodules/logger"));

var _DebugExtendableError = _interopRequireDefault(require("../errors/DebugExtendableError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Downloader {
  /**
   *  Downloader module for oblecto
   *
   * @param { Oblecto } oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.oblecto.queue.registerJob('downloadFile', async job => {
      await Downloader.download(job.url, job.dest, job.overwrite);
    });
  }
  /**
   *  Download a file
   *
   * @param { String } url - URL to download
   * @param { String } dest - Destination path for file
   * @param { Boolean } overwrite - Overwrite if it it exists
   * @returns {Promise<void>}
   */


  static async download(url, dest, overwrite) {
    let flags = 'wx';

    if (overwrite) {
      flags = 'w';
    }

    let {
      data
    } = await (0, _axiosTimeout.default)({
      method: 'get',
      url,
      responseType: 'arraybuffer',
      responseEncoding: 'binary'
    });
    await _fs.promises.writeFile(dest, data, {
      flags
    });
  }
  /**
   *  Download the first url which doesn't return an error code
   *
   * @param { [String] } urls - Array of urls to attempt
   * @param { String } path - Destination path for file
   * @returns {Promise<void>}
   */


  static async attemptDownload(urls, path) {
    for (let url of urls) {
      try {
        await Downloader.download(url, path);
        return;
      } catch (err) {
        _logger.default.log('DEBUG', `Error while downloading ${url}. Continuing to next url`);
      }
    }

    throw new _DebugExtendableError.default('Failed to download any url from array');
  }

}

exports.default = Downloader;