"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _FederationServerConnection = _interopRequireDefault(require("./FederationServerConnection"));

var _file = require("../../../models/file");

var _movie = require("../../../models/movie");

var _episode = require("../../../models/episode");

var _series = require("../../../models/series");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class FederationDataServerConnection extends _FederationServerConnection.default {
  constructor(oblecto, socket) {
    super(oblecto, socket);
    this.fullSyncPermitted = true;
  }

  async headerHandler(data) {
    super.headerHandler(data);
    if (!this.authenticated) return;
    let split = data.split(':');

    switch (split[0]) {
      case 'SYNC':
        this.syncHandler(split[1]);
        break;
    }
  }

  syncHandler(data) {
    if (data === 'FULL') {
      if (!this.fullSyncPermitted) return false;
      return this.startFullSync();
    }
  }

  async startFullSync() {
    await this.syncFiles();
  }

  async syncFiles() {
    let results = await _file.File.findAll({
      include: [_movie.Movie, {
        model: _episode.Episode,
        include: [_series.Series]
      }]
    });

    for (let result of results) {
      if (this.socket.destroyed) return;
      let file = result.toJSON();
      let fileInfo = {};

      if (file.Episodes[0]) {
        fileInfo.type = 'episode';
        fileInfo.episode = file.Episodes[0].airedEpisodeNumber;
        fileInfo.season = file.Episodes[0].airedSeason;
        if (file.Episodes[0].tvdbid) fileInfo.tvdbid = file.Episodes[0].tvdbid;
        if (file.Episodes[0].tmdbid) fileInfo.tmdbid = file.Episodes[0].tmdbid;
        if (file.Episodes[0].Series.tvdbid) fileInfo.seriesTvdbid = file.Episodes[0].Series.tvdbid;
        if (file.Episodes[0].Series.tmdbid) fileInfo.seriesTmdbid = file.Episodes[0].Series.tmdbid;
      }

      if (file.Movies[0]) {
        fileInfo.type = 'movie';
        fileInfo.tmdbid = file.Movies[0].tmdbid;
      }

      let syncInfo = {
        id: file.id,
        duration: file.duration,
        fileInfo
      };
      this.write('FILE', Buffer.from(JSON.stringify(syncInfo)).toString('base64')); // TODO: Negotiate a syncing speed

      await sleep(100);
    }
  }

}

exports.default = FederationDataServerConnection;

function sleep(ms) {
  return new Promise(resolve => {
    setTimeout(resolve, ms);
  });
}