"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _FederationServerConnection = _interopRequireDefault(require("./FederationServerConnection"));

var _file = require("../../../models/file");

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class FederationMediaServerConnection extends _FederationServerConnection.default {
  constructor(oblecto, socket) {
    super(oblecto, socket);
    this.fileId = null;
    this.fileInfo = null;
    this.offset = 0;
  }

  async headerHandler(data) {
    super.headerHandler(data);
    if (!this.authenticated) return;
    let split = data.split(':');

    switch (split[0]) {
      case 'FILEID':
        await this.setFileId(split[1]);
        break;

      case 'OFFSET':
        this.setOffset(split[1]);
        break;

      case 'START':
        await this.startStream();
        break;
    }
  }

  setOffset(offset) {
    this.offset = offset;
  }

  async setFileId(data) {
    this.fileId = data;
    this.fileInfo = null;

    try {
      this.fileInfo = await _file.File.findByPk(this.fileId);
      this.socket.write(`READY:${this.fileId}\n`);
    } catch (e) {
      this.socket.write('ERROR:FILEID\n');
    }
  }

  async startStream() {
    if (!this.fileInfo) return;
    let streamSession = this.oblecto.streamSessionController.newSession(this.fileInfo, {
      streamType: 'recode',
      target: {
        formats: ['matroska'],
        videoCodecs: ['copy'],
        audioCodecs: ['copy']
      },
      offset: this.offset
    });
    await streamSession.addDestination({
      stream: this.socket
    });
    await streamSession.startStream();
  }

  async closeHandler() {
    _logger.default.log('INFO', 'Federation media stream has closed');
  }

}

exports.default = FederationMediaServerConnection;