"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _series = require("../../models/series");

var _episode = require("../../models/episode");

var _file = require("../../models/file");

class FederationEpisodeIndexer {
  constructor(oblecto) {
    this.oblecto = oblecto; // Register task availability to Oblecto queue

    this.oblecto.queue.registerJob('federationIndexEpisode', async job => {
      await this.indexEpisode(job);
    });
  }

  async indexEpisode(file) {
    let [fileEntity, fileInserted] = await _file.File.findOrCreate({
      where: {
        host: file.host,
        path: file.id
      },
      defaults: {
        name: '',
        directory: '',
        extension: '',
        duration: file.duration
      }
    });
    let seriesQuery = {};
    if (file.fileInfo.seriesTvdbid) seriesQuery.tvdbid = file.fileInfo.seriesTvdbid;
    if (file.fileInfo.seriesTmdbid) seriesQuery.tmdbid = file.fileInfo.seriesTmdbid;
    let [series, seriesInserted] = await _series.Series.findOrCreate({
      where: seriesQuery
    });
    let episodeQuery = {
      SeriesId: series.id
    };
    if (file.fileInfo.tvdbid) episodeQuery.tvdbid = file.fileInfo.tvdbid;
    if (file.fileInfo.tmdbid) episodeQuery.tmdbid = file.fileInfo.tmdbid;
    let [episode, episodeInserted] = await _episode.Episode.findOrCreate({
      where: episodeQuery,
      defaults: {
        airedEpisodeNumber: file.fileInfo.episode,
        airedSeason: file.fileInfo.season
      }
    });
    if (!episodeInserted) return;
    await episode.addFile(fileEntity);
    await this.oblecto.seriesUpdateCollector.collectEpisode(episode);
    await this.oblecto.seriesArtworkCollector.collectArtworkEpisodeBanner(episode);
    if (!seriesInserted) return;
    await this.oblecto.seriesUpdateCollector.collectSeries(series);
    await this.oblecto.seriesArtworkCollector.collectArtworkSeriesPoster(series);
  }

}

exports.default = FederationEpisodeIndexer;