"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _AggregateIdentifier = _interopRequireDefault(require("../../common/AggregateIdentifier"));

var _TmdbMovieidentifier = _interopRequireDefault(require("./identifiers/TmdbMovieidentifier"));

var _movie = require("../../../models/movie");

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class MovieIndexer {
  /**
   *
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.movieIdentifier = new _AggregateIdentifier.default();
    const movieIdentifiers = {
      'tmdb': _TmdbMovieidentifier.default
    };

    for (let identifier of this.oblecto.config.movies.movieIdentifiers) {
      _logger.default.log('DEBUG', `Loading ${identifier} movie identifier`);

      this.movieIdentifier.loadIdentifier(new movieIdentifiers[identifier](this.oblecto));
    } // Register task availability to Oblecto queue


    this.oblecto.queue.registerJob('indexMovie', async job => await this.indexFile(job.path, job.doReIndex));
  }
  /**
   * Index file based on file path
   * @param moviePath
   * @returns {Promise<void>}
   */


  async indexFile(moviePath) {
    let file = await this.oblecto.fileIndexer.indexVideoFile(moviePath);
    let movieIdentification = await this.movieIdentifier.identify(moviePath);
    let [movie, movieCreated] = await _movie.Movie.findOrCreate({
      where: {
        tmdbid: movieIdentification.tmdbid
      },
      defaults: movieIdentification
    });
    movie.addFile(file);
    if (!movieCreated) return;
    this.oblecto.queue.queueJob('updateMovie', movie);
    this.oblecto.queue.queueJob('downloadMovieFanart', movie);
    this.oblecto.queue.pushJob('downloadMoviePoster', movie);
  }

}

exports.default = MovieIndexer;