"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _MovieIdentifier = _interopRequireDefault(require("../MovieIdentifier"));

var _guessit = _interopRequireDefault(require("../../../../submodules/guessit"));

var _IdentificationError = _interopRequireDefault(require("../../../errors/IdentificationError"));

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TmdbMovieIdentifier extends _MovieIdentifier.default {
  async identify(path) {
    let identification = await _guessit.default.identify(path);

    if (!identification.title) {
      throw new _IdentificationError.default('Title extraction was unsuccessful');
    }

    let query = {
      query: identification.title
    };

    if (identification.year) {
      query.primary_release_year = identification.year;
    }

    let res = await (0, _promiseTimeout.default)(this.oblecto.tmdb.searchMovie(query, {
      timeout: 5000
    }));
    let identifiedMovie = res.results[0];

    if (!identifiedMovie) {
      throw new _IdentificationError.default();
    }

    return {
      tmdbid: identifiedMovie.id,
      movieName: identifiedMovie.title,
      overview: identifiedMovie.overview
    };
  }

}

exports.default = TmdbMovieIdentifier;