"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _recursiveReaddir = _interopRequireDefault(require("recursive-readdir"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class SeriesCollector {
  /**
   *  Module for oblecto to scan for media files which are to be indexed by the episode indexer
   *
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
  }
  /**
   *  Add all files within a directory to the queue to be indexed
   *
   * @param {String} directory - Which directory to add to the index queue
   * @returns {Promise<void>}
   */


  async collectDirectory(directory) {
    let files = await (0, _recursiveReaddir.default)(directory);
    files.forEach(file => {
      this.collectFile(file);
    });
  }
  /**
   *  Queue a file to be indexed
   *
   * @param {String} file - File path to add to the index queue
   * @returns {Promise<void>}
   */


  async collectFile(file) {
    let extension = _path.default.parse(file).ext.toLowerCase();

    if (this.oblecto.config.fileExtensions.video.indexOf(extension) !== -1) {
      this.oblecto.queue.queueJob('indexEpisode', {
        path: file
      });
    }
  }
  /**
   * Index all TV Show libraries
   *
   * @returns {Promise<void>}
   */


  async collectAll() {
    this.oblecto.config.tvshows.directories.forEach(directory => {
      this.collectDirectory(directory.path);
    });
  }

}

exports.default = SeriesCollector;