"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _guessit = _interopRequireDefault(require("../../../../submodules/guessit"));

var _IdentificationError = _interopRequireDefault(require("../../../errors/IdentificationError"));

var _EpisodeIdentifier = _interopRequireDefault(require("../EpisodeIdentifier"));

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TmdbEpisodeIdentifier extends _EpisodeIdentifier.default {
  /**
   *  Identify an episode using TMDB
   *
   * @param { String } path - Path to the episode to be identified
   * @param guessitIdentification
   * @param { Series } series - Series to which the episode should belong
   * @returns {Promise<{overview: *, tmdbid: *, episodeName: *, firstAired: *, airedSeason: *, airedEpisodeNumber: *}>}
   */
  async identify(path, guessitIdentification, series) {
    if (!series.tmdbid) throw new _IdentificationError.default();
    let episode = await (0, _promiseTimeout.default)(this.oblecto.tmdb.episodeInfo({
      id: series.tmdbid,
      season_number: guessitIdentification.season || 1,
      episode_number: guessitIdentification.episode
    }, {
      timeout: 5000
    }));
    return {
      tmdbid: episode.id,
      episodeName: episode.name,
      airedEpisodeNumber: episode.episode_number,
      airedSeason: episode.season_number,
      overview: episode.overview,
      firstAired: episode.air_date
    };
  }

}

exports.default = TmdbEpisodeIdentifier;