"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _IdentificationError = _interopRequireDefault(require("../../../errors/IdentificationError"));

var _EpisodeIdentifier = _interopRequireDefault(require("../EpisodeIdentifier"));

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TvdbEpisodeIdentifier extends _EpisodeIdentifier.default {
  constructor(oblecto) {
    super(oblecto);
    this.episodeCache = {};
  }
  /**
   * Get all episodes from TVDB from a given TVDB series id
   *
   * @param { Number } tvdbId
   * @returns {Promise<*>}
   */


  async getEpisodes(tvdbId) {
    // TODO: Caching should be moved somewhere else or at least improved. This implementation is terrible
    if (this.episodeCache[tvdbId]) {
      return this.episodeCache[tvdbId];
    }

    if (this.episodeCache.length > 100) this.episodeCache = {};
    this.episodeCache[tvdbId] = await (0, _promiseTimeout.default)(this.oblecto.tvdb.getEpisodesBySeriesId(tvdbId));
    return this.episodeCache[tvdbId];
  }
  /**
   * Match an episode to given guessit identification
   *
   * @param { Series } series
   */


  async retrieveEpisode(series, guessitIdentification) {
    let tvdbEpisodes = await this.getEpisodes(series.tvdbid);

    for (let episode of tvdbEpisodes) {
      if (episode.episodeName === guessitIdentification.episode_name) return episode;
      if (episode.airedSeason !== guessitIdentification.season) continue;
      if (episode.airedEpisodeNumber !== guessitIdentification.episode) continue;
      return episode;
    }

    throw new _IdentificationError.default();
  }
  /**
   *  Identify an episode using TVDB
   *
   * @param { String } path - Path to the episode to be identified
   * @param guessitIdentification
   * @param { Series } series - Series to which the episode should belong
   * @returns {Promise<{overview: *, tmdbid: *, episodeName: *, firstAired: *, airedSeason: *, airedEpisodeNumber: *}>}
   */


  async identify(path, guessitIdentification, series) {
    if (!series.tvdbid) throw new _IdentificationError.default('tvdbid was not supplied');
    let episode = await this.retrieveEpisode(series, guessitIdentification);
    return {
      tvdbid: episode.id,
      imdbid: episode.imdbId,
      episodeName: episode.episodeName,
      airedEpisodeNumber: episode.airedEpisodeNumber,
      airedSeason: episode.airedSeason,
      dvdEpisodeNumber: episode.dvdEpisodeNumber,
      dvdSeason: episode.dvdSeason,
      absoluteNumber: episode.absoluteNumber,
      overview: episode.overview,
      firstAired: episode.firstAired
    };
  }

}

exports.default = TvdbEpisodeIdentifier;