"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _nodeTvdb = _interopRequireDefault(require("node-tvdb"));

var _moviedbPromise = require("moviedb-promise");

var _queue = _interopRequireDefault(require("../queue"));

var _ArtworkScaler = _interopRequireDefault(require("../artwork/ArtworkScaler"));

var _downloader = _interopRequireDefault(require("../downloader"));

var _SeriesIndexer = _interopRequireDefault(require("../indexers/series/SeriesIndexer"));

var _MovieIndexer = _interopRequireDefault(require("../indexers/movies/MovieIndexer"));

var _SeriesCollector = _interopRequireDefault(require("../indexers/series/SeriesCollector"));

var _MovieCollector = _interopRequireDefault(require("../indexers/movies/MovieCollector"));

var _REST = _interopRequireDefault(require("../../submodules/REST"));

var _RealtimeController = _interopRequireDefault(require("../realtime/RealtimeController"));

var _ArtworkUtils = _interopRequireDefault(require("../artwork/ArtworkUtils"));

var _MovieArtworkCollector = _interopRequireDefault(require("../artwork/movies/MovieArtworkCollector"));

var _SeriesArtworkCollector = _interopRequireDefault(require("../artwork/series/SeriesArtworkCollector"));

var _SeriesArtworkDownloader = _interopRequireDefault(require("../artwork/series/SeriesArtworkDownloader"));

var _MovieArtworkDownloader = _interopRequireDefault(require("../artwork/movies/MovieArtworkDownloader"));

var _FileUpdater = _interopRequireDefault(require("../updaters/files/FileUpdater"));

var _SeriesUpdater = _interopRequireDefault(require("../updaters/series/SeriesUpdater"));

var _MovieUpdater = _interopRequireDefault(require("../updaters/movies/MovieUpdater"));

var _FileUpdateCollector = _interopRequireDefault(require("../updaters/files/FileUpdateCollector"));

var _SeriesUpdateCollector = _interopRequireDefault(require("../updaters/series/SeriesUpdateCollector"));

var _MovieUpdateCollector = _interopRequireDefault(require("../updaters/movies/MovieUpdateCollector"));

var _FederationController = _interopRequireDefault(require("../federation/server/FederationController"));

var _FederationClientController = _interopRequireDefault(require("../federation/client/FederationClientController"));

var _FederationEpisodeIndexer = _interopRequireDefault(require("../federationindexer/FederationEpisodeIndexer"));

var _FederationMovieIndexer = _interopRequireDefault(require("../federationindexer/FederationMovieIndexer"));

var _MovieCleaner = _interopRequireDefault(require("../cleaners/MovieCleaner"));

var _SeriesCleaner = _interopRequireDefault(require("../cleaners/SeriesCleaner"));

var _FileCleaner = _interopRequireDefault(require("../cleaners/FileCleaner"));

var _FileIndexer = _interopRequireDefault(require("../indexers/files/FileIndexer"));

var _database = require("../../submodules/database");

var _StreamSessionController = _interopRequireDefault(require("../streamSessions/StreamSessionController"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Oblecto {
  constructor(config) {
    this.config = config;
    this.database = (0, _database.initDatabase)();
    this.tvdb = new _nodeTvdb.default(this.config.tvdb.key);
    this.tmdb = new _moviedbPromise.MovieDb(this.config.themoviedb.key);
    this.queue = new _queue.default(this.config.queue.concurrency);
    this.oblectoAPI = new _REST.default(this);
    this.realTimeController = new _RealtimeController.default(this);
    this.downloader = new _downloader.default(this);
    this.fileIndexer = new _FileIndexer.default(this);
    this.seriesIndexer = new _SeriesIndexer.default(this);
    this.movieIndexer = new _MovieIndexer.default(this);
    this.seriesCollector = new _SeriesCollector.default(this);
    this.movieCollector = new _MovieCollector.default(this);
    this.seriesArtworkDownloader = new _SeriesArtworkDownloader.default(this);
    this.movieArtworkDownloader = new _MovieArtworkDownloader.default(this);
    this.movieArtworkCollector = new _MovieArtworkCollector.default(this);
    this.seriesArtworkCollector = new _SeriesArtworkCollector.default(this);
    this.artworkUtils = new _ArtworkUtils.default(this);
    this.imageScaler = new _ArtworkScaler.default(this);
    this.fileUpdater = new _FileUpdater.default(this);
    this.seriesUpdater = new _SeriesUpdater.default(this);
    this.movieUpdater = new _MovieUpdater.default(this);
    this.fileUpdateCollector = new _FileUpdateCollector.default(this);
    this.seriesUpdateCollector = new _SeriesUpdateCollector.default(this);
    this.movieUpdateCollector = new _MovieUpdateCollector.default(this);
    this.fileCleaner = new _FileCleaner.default(this);
    this.movieCleaner = new _MovieCleaner.default(this);
    this.seriesCleaner = new _SeriesCleaner.default(this);
    this.streamSessionController = new _StreamSessionController.default(this);

    if (config.federation.enable) {
      this.fedartionController = new _FederationController.default(this);
      this.federationClientController = new _FederationClientController.default(this);
      this.federationEpisodeIndexer = new _FederationEpisodeIndexer.default(this);
      this.federationMovieIndexer = new _FederationMovieIndexer.default(this);
      this.federationClientController.addAllSyncMasters();
    }
  }

  close() {
    for (let item of Object.keys(this)) {
      if (this[item].close) {
        this[item].close();
      }
    }
  }

}

exports.default = Oblecto;