"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _async = _interopRequireDefault(require("async"));

var _logger = _interopRequireDefault(require("../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Queue {
  /**
   *
   * @param { Number } concurrency - Amount of tasks to handle simultaneously
   */
  constructor(concurrency) {
    this.jobs = {};
    this.queue = _async.default.priorityQueue((job, callback) => {
      if (!this.jobs[job.id]) return callback();
      let jobTimeout = setTimeout(() => {
        _logger.default.log('WARN', `Job ${job.id} is taking a long time. Maybe something is wrong?`, JSON.stringify(job));
      }, 20000);
      this.jobs[job.id](job.attr).then(() => {
        clearTimeout(jobTimeout);
        callback();
      }).catch(err => {
        clearTimeout(jobTimeout);

        _logger.default.log(err);

        callback();
      });
    }, concurrency);
  }
  /**
   *  Define a new job
   * @param {string} id
   * @param {function} job
   */


  registerJob(id, job) {
    if (this.jobs[id]) {
      _logger.default.log('ERROR', `A job has been registered which was already registered: ${id}`);

      _logger.default.log('ERROR', 'This should not happen. Shutting down server');

      this.oblecto.close();
      return;
    }

    _logger.default.log('INFO', 'New queue item has been registered:', id);

    this.jobs[id] = job;
  }
  /**
   *  Add a job to the end of the queue
   * @param {string} id
   * @param {object} attr
   * @param {number} priority
   */


  queueJob(id, attr, priority = 5) {
    this.queue.push({
      id,
      attr
    }, priority);
  }
  /**
   *  Adds a queue which should be completed as soon as possible
   * @param {string} id
   * @param {object} attr
   */


  lowPriorityJob(id, attr) {
    this.queueJob(id, attr, 20);
  }
  /**
   *  Add a job to the front of the queue
   * @param {string} id
   * @param {object} attr
   */


  pushJob(id, attr) {
    this.queueJob(id, attr, 0);
  }

}

exports.default = Queue;