"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _DirectStreamSession = _interopRequireDefault(require("./StreamSessionTypes/DirectStreamSession"));

var _DirectHttpStreamSession = _interopRequireDefault(require("./StreamSessionTypes/DirectHttpStreamSession"));

var _RecodeStreamSession = _interopRequireDefault(require("./StreamSessionTypes/RecodeStreamSession"));

var _RecodeFederationStreamSession = _interopRequireDefault(require("./StreamSessionTypes/RecodeFederationStreamSession"));

var _logger = _interopRequireDefault(require("../../submodules/logger"));

var _HLSStreamer = _interopRequireDefault(require("./StreamSessionTypes/HLSStreamer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class StreamSessionController {
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.sessions = {};
  }
  /**
   *
   * @param {File} file
   * @param options
   * @returns {StreamSession}
   */


  newSession(file, options) {
    const streamSession = this.createSession(file, options);
    this.sessions[streamSession.sessionId] = streamSession;
    streamSession.on('close', () => {
      _logger.default.log('INFO', streamSession.sessionId, 'has ended');

      delete this.sessions[streamSession.sessionId];
    });
    return streamSession;
  }

  createSession(file, options) {
    if (file.host !== 'local') {
      return new _RecodeFederationStreamSession.default(file, options, this.oblecto);
    }

    if (options.streamType === 'hls') {
      return new _HLSStreamer.default(file, options, this.oblecto);
    }

    if (this.oblecto.config.transcoding.transcodeEverything) {
      return new _RecodeStreamSession.default(file, options, this.oblecto);
    }

    if (options.streamType === 'direct') {
      return new _DirectStreamSession.default(file, options, this.oblecto);
    }

    if (options.streamType === 'directhttp') {
      return new _DirectHttpStreamSession.default(file, options, this.oblecto);
    }

    if (options.streamType === 'recode') {
      return new _RecodeStreamSession.default(file, options, this.oblecto);
    }
  }

  sessionExists(sessionId) {
    return this.sessions[sessionId] !== undefined;
  }

}

exports.default = StreamSessionController;