"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _StreamSession = _interopRequireDefault(require("../StreamSession"));

var _mkdirp = _interopRequireDefault(require("mkdirp"));

var _os = _interopRequireDefault(require("os"));

var _ffmpeg = _interopRequireDefault(require("../../../submodules/ffmpeg"));

var _fs = _interopRequireWildcard(require("fs"));

var _DirectHttpStreamSession = _interopRequireDefault(require("./DirectHttpStreamSession"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class HLSStreamer extends _StreamSession.default {
  constructor(file, options, oblecto) {
    super(file, options, oblecto);
    this.timeoutTime = 10000;
    this.paused = true;
    this.maxGenCount = 10;

    if (this.videoCodec === this.file.videoCodec || this.file.videoCodec in this.targetVideoCodecs) {
      this.videoCodec = 'copy';
    }

    if (this.audioCodec === this.file.audioCodec || this.file.audioCodec in this.targetAudioCodecs) {
      this.audioCodec = 'copy';
    }

    this.startTimeout(); // Create temporary directory to store HLS segments

    _mkdirp.default.sync(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}`);

    this.process = (0, _ffmpeg.default)(this.file.path) //.native()
    .videoCodec(this.getFfmpegVideoCodec()).audioCodec(this.audioCodec).seekInput(this.offset).outputOptions([//'-hls_time 10',
    //'-hls_list_size 10',
    //'-hls_init_time 2',
    '-hls_playlist_type event', '-hls_base_url', `/HLS/${this.sessionId}/segment/`, '-hls_segment_filename', `${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/%03d.ts`]);
    this.process.on('start', cmd => this.segmenterStart(cmd));
    this.process.on('error', err => {});
    this.segmentCheckerInterval = setInterval(() => this.segmentChecker(), 100);
    this.startSegmenter();
  }

  async endSession() {
    super.endSession();
    clearInterval(this.segmentCheckerInterval);
    await _fs.promises.rmdir(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/`, {
      recursive: true
    });
  }

  segmenterStart(cmd) {
    this.paused = false;
  }

  startSegmenter() {
    this.process.save(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/index.m3u8`);
  }

  async segmentChecker() {
    if (!this.process) return;
    let files = await _fs.promises.readdir(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/`);
    const segments = files.filter(s => s.includes('.ts'));

    if (segments.length > this.maxGenCount) {
      this.pauseSegmenting();
    } else {
      this.resumeSegmenting();
    }
  }

  pauseSegmenting() {
    if (!this.process) return;
    if (this.paused) return;
    this.paused = true;
    this.process.kill('SIGSTOP');
  }

  resumeSegmenting() {
    if (!this.process) return;
    if (!this.paused) return;
    this.paused = false;
    this.process.kill('SIGCONT');
  }

  sendPlaylistFile(res) {
    this.startTimeout();
    res.writeHead(200, {
      'Content-Type': 'application/x-mpegURL'
    });

    _fs.default.createReadStream(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/index.m3u8`).pipe(res);
  }

  async streamSegment(req, res, segmentId) {
    this.clearTimeout();
    res.on('close', () => {
      this.startTimeout();
    });

    _DirectHttpStreamSession.default.httpStreamHandler(req, res, `${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/${('000' + segmentId).substr(-3)}.ts`);

    let files = await _fs.promises.readdir(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/`);

    for (let file of files) {
      let sequenceId = file.replace('index', '').replace('.vtt', '').replace('.ts', '');
      sequenceId = parseInt(sequenceId);

      if (segmentId > sequenceId) {
        await _fs.promises.unlink(`${_os.default.tmpdir()}/oblecto/sessions/${this.sessionId}/${file}`);
      }
    }
  }

  async addDestination(destination) {
    this.destinations.push(destination);
    destination.stream.on('close', () => {
      for (let i in this.destinations) {
        if (this.destinations[i].stream === destination.stream) {
          this.destinations.splice(i, 1);
        }
      }
    });
  }

  async startStream() {
    for (let {
      stream
    } of this.destinations) {
      this.sendPlaylistFile(stream);
    }
  }

}

exports.default = HLSStreamer;