"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _StreamSession = _interopRequireDefault(require("../StreamSession"));

var _ffmpeg = _interopRequireDefault(require("../../../submodules/ffmpeg"));

var _stream = _interopRequireDefault(require("stream"));

var _FederationMediaClient = _interopRequireDefault(require("../../federation/client/FederationMediaClient"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class RecodeFederationStreamSession extends _StreamSession.default {
  constructor(file, options, oblecto) {
    super(file, options, oblecto);
  }

  async addDestination(destination) {
    await super.addDestination(destination);
  }

  endSession() {
    super.endSession();
    this.federationClient.closeConnection();
  }

  async startStream() {
    await super.startStream();
    if (this.started) return;
    this.started = true;
    await this.initFederationStream();
    let inputOptions = ['-noaccurate_seek'];
    let outputOptions = ['-movflags', 'empty_moov', '-copyts'];

    if (this.oblecto.config.transcoding.hardwareAcceleration) {
      inputOptions.push('-hwaccel ' + this.oblecto.config.transcoding.hardwareAccelerator); // The Nvidia NVENC encoder doesn't support 10 bit encoding, so we need to force 8 bit
      // if the cuda accelerator has been selected

      if (this.oblecto.config.transcoding.hardwareAccelerator === 'cuda') {
        outputOptions.push('-pix_fmt yuv420p');
      }
    }

    this.process = (0, _ffmpeg.default)(this.inputStream).format(this.format).videoCodec(this.getFfmpegVideoCodec()).audioCodec(this.audioCodec).inputOptions(inputOptions).outputOptions(outputOptions).on('start', cmd => {
      _logger.default.log('INFO', this.sessionId, cmd);
    });
    this.process.on('error', err => {
      if (err.message !== 'ffmpeg was killed with signal SIGKILL') _logger.default.log('ERROR', this.sessionId, err);
    });
    this.process.pipe(this.outputStream, {
      end: true
    });
  }

  async initFederationStream() {
    this.federationClient = new _FederationMediaClient.default(this.oblecto, this.file.host);
    await this.federationClient.connect();
    await this.federationClient.setStreamDestination(this.inputStream);
    await this.federationClient.setStreamOffset(this.offset);
    await this.federationClient.startStreamFile(this.file.path);
  }

}

exports.default = RecodeFederationStreamSession;