"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _StreamSession = _interopRequireDefault(require("../StreamSession"));

var _ffmpeg = _interopRequireDefault(require("../../../submodules/ffmpeg"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class RecodeStreamSession extends _StreamSession.default {
  constructor(file, options, oblecto) {
    super(file, options, oblecto); // LanguageCode is the ISO 639-2 code for the desired language

    this.targetLanguageCode = oblecto.config.streaming.defaultTargetLanguageCode;

    if (this.videoCodec === this.file.videoCodec || this.file.videoCodec in this.targetVideoCodecs) {
      this.videoCodec = 'copy';
    }

    if (this.audioCodec === this.file.audioCodec || this.file.audioCodec in this.targetAudioCodecs) {
      this.audioCodec = 'copy';
    }
  }

  async addDestination(destination) {
    await super.addDestination(destination);
  }

  async startStream() {
    var _audioStreams$, _videoStreams$;

    await super.startStream();
    if (this.started) return;
    this.started = true;
    let inputOptions = ['-noaccurate_seek'];
    let outputOptions = ['-movflags empty_moov', '-copyts', '-preset ultrafast', '-tune zerolatency'];

    if (this.oblecto.config.transcoding.hardwareAcceleration) {
      inputOptions.push('-hwaccel ' + this.oblecto.config.transcoding.hardwareAccelerator); // The Nvidia NVENC encoder doesn't support 10 bit encoding, so we need to force 8 bit
      // if the cuda accelerator has been selected
      // TODO: Fix washed out colors for some 10 bit video streams when using the NVENC encoder
      //       Depending on the input color range, this may result in washed out colors since the
      //       color range is kept but considered to be a full range color space even if the input
      //       range is limited.

      if (this.oblecto.config.transcoding.hardwareAccelerator === 'cuda') {
        outputOptions.push('-pix_fmt yuv420p');
      }
    }

    let streams = await this.file.getStreams();
    let audioStreams = [];
    let videoStreams = [];

    for (let stream of streams) {
      if (stream.codec_type === 'video') videoStreams.push(stream);
      if (stream.codec_type === 'audio') audioStreams.push(stream);
    } // Define default streams. We don't want to end up with a video without any audio or video streams


    let selectedAudioStream = audioStreams === null || audioStreams === void 0 ? void 0 : (_audioStreams$ = audioStreams[0]) === null || _audioStreams$ === void 0 ? void 0 : _audioStreams$.index;
    let selectedVideoStream = videoStreams === null || videoStreams === void 0 ? void 0 : (_videoStreams$ = videoStreams[0]) === null || _videoStreams$ === void 0 ? void 0 : _videoStreams$.index; // Find a video stream with the desired language code
    // TODO: Some languages may be identified by multiple language codes
    //       EG: French sometimes uses both "Fra" and "Fre"

    for (let stream of audioStreams) {
      if (stream.tags_language === this.targetLanguageCode && stream.index !== undefined) {
        selectedAudioStream = stream.index;
      }
    }

    if (!(selectedVideoStream === undefined || selectedAudioStream === undefined)) {
      outputOptions.push(`-map 0:${selectedAudioStream}`);
      outputOptions.push(`-map 0:${selectedVideoStream}`);
    }

    this.process = (0, _ffmpeg.default)(this.file.path).format(this.format).videoCodec(this.getFfmpegVideoCodec()).audioCodec(this.audioCodec).seekInput(this.offset).inputOptions(inputOptions).outputOptions(outputOptions).on('start', cmd => {
      _logger.default.log('INFO', this.sessionId, cmd);
    });
    this.process.on('error', err => {
      if (err.message !== 'ffmpeg was killed with signal SIGKILL') _logger.default.log('ERROR', this.sessionId, err);
    });
    this.process.pipe(this.outputStream, {
      end: true
    });
  }

}

exports.default = RecodeStreamSession;