"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _AggregateUpdateRetriever = _interopRequireDefault(require("../../common/AggregateUpdateRetriever"));

var _TmdbSeriesRetriever = _interopRequireDefault(require("./informationRetrievers/TmdbSeriesRetriever"));

var _TmdbEpisodeRetriever = _interopRequireDefault(require("./informationRetrievers/TmdbEpisodeRetriever"));

var _TvdbEpisodeRetriever = _interopRequireDefault(require("./informationRetrievers/TvdbEpisodeRetriever"));

var _TvdbSeriesRetriever = _interopRequireDefault(require("./informationRetrievers/TvdbSeriesRetriever"));

var _logger = _interopRequireDefault(require("../../../submodules/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class SeriesUpdater {
  /**
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
    this.aggregateSeriesUpdateRetriever = new _AggregateUpdateRetriever.default();
    this.aggregateEpisodeUpdaterRetriever = new _AggregateUpdateRetriever.default();
    const seriesUpdateRetrievers = {
      'tmdb': _TmdbSeriesRetriever.default,
      'tvdb': _TvdbSeriesRetriever.default
    };
    const episodeUpdateRetrievers = {
      'tmdb': _TmdbEpisodeRetriever.default,
      'tvdb': _TvdbEpisodeRetriever.default
    };

    for (let updater of this.oblecto.config.tvshows.seriesUpdaters) {
      _logger.default.log('DEBUG', `Loading ${updater} series updater`);

      this.aggregateSeriesUpdateRetriever.loadRetriever(new seriesUpdateRetrievers[updater](this.oblecto));
    }

    for (let updater of this.oblecto.config.tvshows.episodeUpdaters) {
      _logger.default.log('DEBUG', `Loading ${updater} episode updater`);

      this.aggregateEpisodeUpdaterRetriever.loadRetriever(new episodeUpdateRetrievers[updater](this.oblecto));
    } // Register task availability to Oblecto queue


    this.oblecto.queue.registerJob('updateEpisode', async job => {
      await this.updateEpisode(job);
    });
    this.oblecto.queue.registerJob('updateSeries', async job => {
      await this.updateSeries(job);
    });
  }
  /**
   *
   * @param {Series} series
   * @returns {Promise<void>}
   */


  async updateSeries(series) {
    let data = await this.aggregateSeriesUpdateRetriever.retrieveInformation(series);
    await series.update(data);
  }
  /**
   *
   * @param {Episode} episode
   * @returns {Promise<void>}
   */


  async updateEpisode(episode) {
    let data = await this.aggregateEpisodeUpdaterRetriever.retrieveInformation(episode);
    await episode.update(data);
  }

}

exports.default = SeriesUpdater;