"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _logger = _interopRequireDefault(require("../../../../submodules/logger"));

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

var _DebugExtendableError = _interopRequireDefault(require("../../../errors/DebugExtendableError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TmdbEpisodeRetriever {
  constructor(oblecto) {
    this.oblecto = oblecto;
  }

  async retrieveInformation(episode) {
    let series = await episode.getSeries();
    if (!series.tmdbid) throw new _DebugExtendableError.default('No tmdbid attached to series');
    let episodeInfo = await (0, _promiseTimeout.default)(this.oblecto.tmdb.episodeInfo({
      id: series.tmdbid,
      season_number: episode.airedSeason,
      episode_number: episode.airedEpisodeNumber
    }, {
      timeout: 5000
    }));

    _logger.default.log('DEBUG', `Episode information for ${episode.episodeName} retrieved from tmdb`);

    let data = {
      episodeName: episodeInfo.name,
      airedEpisodeNumber: episodeInfo.episode_number,
      airedSeason: episodeInfo.season_number,
      overview: episodeInfo.overview,
      firstAired: episodeInfo.air_date
    };
    let externalIds = {};

    if (!(episode.tvdbid && episode.imdbid)) {
      _logger.default.log('DEBUG', `External ids for ${episode.episodeName} missing`);

      externalIds = await (0, _promiseTimeout.default)(this.oblecto.tmdb.episodeExternalIds({
        id: series.tmdbid,
        season_number: episode.airedSeason,
        episode_number: episode.airedEpisodeNumber
      }, {
        timeout: 5000
      }));

      _logger.default.log('DEBUG', `External ids for ${episode.episodeName} retrieved`);
    }

    if (!episode.tvdbid && externalIds.tvdb_id) {
      data.tvdbid = externalIds.tvdb_id;
    }

    if (!episode.imdbid && externalIds.imdb_id) {
      data.imdbid = externalIds.imdb_id;
    }

    return data;
  }

}

exports.default = TmdbEpisodeRetriever;