"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

var _DebugExtendableError = _interopRequireDefault(require("../../../errors/DebugExtendableError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TmdbSeriesRetriever {
  /**
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
  }
  /**
   *
   * @param {Series} series
   * @returns {Promise<{overview: *, siteRating: *, seriesName: *, firstAired: *, popularity: *, siteRatingCount: *, status: *}>}
   */


  async retrieveInformation(series) {
    if (!series.tmdbid) throw new _DebugExtendableError.default('No tmdbid attached to series');
    const seriesInfo = await (0, _promiseTimeout.default)(this.oblecto.tmdb.tvInfo({
      id: series.tmdbid
    }, {
      timeout: 5000
    }));
    let data = {
      seriesName: seriesInfo.name,
      status: seriesInfo.status,
      firstAired: seriesInfo.first_air_date,
      overview: seriesInfo.overview,
      popularity: seriesInfo.popularity,
      siteRating: seriesInfo.vote_average,
      siteRatingCount: seriesInfo.vote_count,
      genre: JSON.stringify(seriesInfo.genres.map(i => i.name))
    };
    let externalIds = {};

    if (!(series.tvdbid && series.imdbid)) {
      externalIds = await (0, _promiseTimeout.default)(this.oblecto.tmdb.tvExternalIds({
        id: series.tmdbid
      }, {
        timeout: 5000
      }));
    }

    if (!series.tvdbid) {
      data.tvdbid = externalIds.tvdb_id;
    }

    if (!series.imdbid) {
      data.imdbid = externalIds.imdb_id;
    }

    return data;
  }

}

exports.default = TmdbSeriesRetriever;