"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _promiseTimeout = _interopRequireDefault(require("../../../../submodules/promiseTimeout"));

var _DebugExtendableError = _interopRequireDefault(require("../../../errors/DebugExtendableError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TvdbSeriesRetriever {
  /**
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto;
  }
  /**
   *
   * @param {Series} series
   * @returns {Promise<{overview: *, siteRating: *, seriesName: *, firstAired: *, popularity: *, siteRatingCount: *, status: *}>}
   */


  async retrieveInformation(series) {
    if (!series.tvdbid) throw new _DebugExtendableError.default('No tvdbid attached to series');
    let seriesInfo = await (0, _promiseTimeout.default)(this.oblecto.tvdb.getSeriesById(series.tvdbid)); //TODO: TMDB Voting should be separated from TVDB voting

    return {
      seriesName: seriesInfo.seriesName,
      status: seriesInfo.status,
      firstAired: seriesInfo.firstAired,
      overview: seriesInfo.overview,
      siteRating: seriesInfo.siteRating,
      siteRatingCount: seriesInfo.siteRatingCount,
      rating: seriesInfo.rating,
      airsDayOfWeek: seriesInfo.airsDayOfWeek,
      airsTime: seriesInfo.airsTime,
      network: seriesInfo.network,
      imdbid: seriesInfo.imdbId || null,
      zap2itId: seriesInfo.zap2itId || null
    };
  }

}

exports.default = TvdbSeriesRetriever;