"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _restify = _interopRequireDefault(require("restify"));

var _routes = _interopRequireDefault(require("./routes"));

var _restifyCorsMiddleware = _interopRequireDefault(require("restify-cors-middleware"));

var _logger = _interopRequireDefault(require("../logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class OblectoAPI {
  /**
   * @param {Oblecto} oblecto
   */
  constructor(oblecto) {
    this.oblecto = oblecto; // Initialize REST based server

    this.server = _restify.default.createServer({
      'name': 'Oblecto'
    }); // Allow remote clients to connect to the backend

    const cors = (0, _restifyCorsMiddleware.default)({
      preflightMaxAge: 5,
      //Optional
      origins: ['*'],
      allowHeaders: ['API-Token', 'authorization'],
      exposeHeaders: ['API-Token-Expiry']
    });
    this.server.pre(cors.preflight);
    this.server.use(cors.actual);
    this.server.use(_restify.default.plugins.authorizationParser());
    this.server.use(_restify.default.plugins.queryParser({
      mapParams: true
    }));
    this.server.use(_restify.default.plugins.bodyParser({
      mapParams: true
    })); // Add routes routes

    (0, _routes.default)(this.server, this.oblecto); // Start restify server

    this.server.listen(this.oblecto.config.server.port, () => {
      _logger.default.log('INFO', this.server.name, 'REST API Listening at', this.server.url);
    });
  }

  close() {
    this.server.close();
  }

}

exports.default = OblectoAPI;