"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _restifyErrors = _interopRequireDefault(require("restify-errors"));

var _auth = _interopRequireDefault(require("../middleware/auth"));

var _file = require("../../../models/file");

var _sequelize = _interopRequireDefault(require("sequelize"));

var _episode = require("../../../models/episode");

var _movie = require("../../../models/movie");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * @param {Server} server
 * @param {Oblecto} oblecto
 */
var _default = (server, oblecto) => {
  server.get('/files/duplicates', _auth.default.requiresAuth, async function (req, res, next) {
    const fileHashCounts = await _file.File.findAll({
      attributes: ['hash', [_sequelize.default.fn('COUNT', _sequelize.default.col('hash')), 'count']],
      group: ['hash'],
      order: [[_sequelize.default.fn('COUNT', _sequelize.default.col('hash')), 'DESC']]
    });
    let duplicates = [];

    for (const fileHashCount of fileHashCounts) {
      // The list of file hashes with counts is sorted descending,
      // which means that once we have reached an item with a duplicate count of less then 2,
      // no files be any duplicates anymore.
      if (fileHashCount.toJSON().count <= 1) break;
      duplicates.push(await _file.File.findAll({
        where: {
          hash: fileHashCount.hash
        },
        include: [_episode.Episode, _movie.Movie]
      }));
    }

    res.send(duplicates);
  });
};

exports.default = _default;