"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _restifyErrors = _interopRequireDefault(require("restify-errors"));

var _sequelize = _interopRequireDefault(require("sequelize"));

var _sharp = _interopRequireDefault(require("sharp"));

var _auth = _interopRequireDefault(require("../middleware/auth"));

var _trackMovie = require("../../../models/trackMovie");

var _file = require("../../../models/file");

var _movie = require("../../../models/movie");

var _movieSet = require("../../../models/movieSet");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Op = _sequelize.default.Op;

var _default = (server, oblecto) => {
  server.get('/movies/list/:sorting', _auth.default.requiresAuth, async function (req, res, next) {
    let limit = 20;
    let page = 0;
    let AllowedOrders = ['desc', 'asc'];
    if (AllowedOrders.indexOf(req.params.order.toLowerCase()) === -1) return next(new _restifyErrors.default.BadRequestError('Sorting order is invalid'));
    if (!(req.params.sorting in _movie.Movie.rawAttributes)) return next(new _restifyErrors.default.BadRequestError('Sorting method is invalid'));
    if (req.params.count && Number.isInteger(req.params.count)) limit = parseInt(req.params.count);
    if (req.params.page && Number.isInteger(req.params.page)) page = parseInt(req.params.page);
    let results = await _movie.Movie.findAll({
      include: [{
        model: _trackMovie.TrackMovie,
        required: false,
        where: {
          userId: req.authorization.user.id
        }
      }],
      order: [[req.params.sorting, req.params.order]],
      limit,
      offset: limit * page
    });
    res.send(results);
  });
  server.get('/movies/sets', _auth.default.requiresAuth, async function (req, res) {
    let results = await _movieSet.MovieSet.findAll({});
    res.send(results);
  });
  server.get('/movies/set/:id', _auth.default.requiresAuth, async function (req, res, next) {
    let limit = req.params.count || 20;
    let page = req.params.page || 0;
    if (!Number.isInteger(limit) || !Number.isInteger(page)) return next(new _restifyErrors.default.BadRequestError('Limit or Page must be a number'));
    let AllowedOrders = ['desc', 'asc'];
    if (AllowedOrders.indexOf(req.params.order.toLowerCase()) === -1) return next(new _restifyErrors.default.BadRequestError('Sorting order is invalid'));
    let results = await _movieSet.MovieSet.findAll({
      include: [{
        model: _movie.Movie,
        include: [{
          model: _trackMovie.TrackMovie,
          required: false,
          where: {
            userId: req.authorization.user.id
          }
        }]
      }],
      where: {
        id: req.params.id
      },
      limit,
      offset: limit * page
    });
    res.send(results);
  });
  server.get('/movie/:id/poster', async function (req, res, next) {
    // Get episode data
    let movie;

    try {
      movie = await _movie.Movie.findByPk(req.params.id);
    } catch (e) {
      return next(new _restifyErrors.default.NotFoundError('Movie not found'));
    }

    let posterPath = oblecto.artworkUtils.moviePosterPath(movie, req.params.size || 'medium');

    _fs.default.createReadStream(posterPath).on('error', () => {
      return next(new _restifyErrors.default.NotFoundError('Poster for movie does not exist'));
    }).pipe(res);
  });
  server.put('/movie/:id/poster', _auth.default.requiresAuth, async function (req, res, next) {
    let movie = await _movie.Movie.findByPk(req.params.id, {
      include: [_file.File]
    });

    if (!movie) {
      return next(new _restifyErrors.default.NotFoundError('Movie does not exist'));
    }

    let posterPath = oblecto.artworkUtils.moviePosterPath(movie);

    if (req.files.length < 1) {
      return next(new _restifyErrors.default.MissingParameter('Image file is missing'));
    }

    let uploadPath = req.files[Object.keys(req.files)[0]].path;

    try {
      let image = await (0, _sharp.default)(uploadPath);
      let metadata = await image.metadata();
      let ratio = metadata.height / metadata.width;

      if (!(1 <= ratio <= 2)) {
        return next(new _restifyErrors.default.InvalidContent('Image aspect ratio is incorrect'));
      }
    } catch (e) {
      return next(new _restifyErrors.default.InvalidContent('File is not an image'));
    }

    try {
      _fs.default.copyFile(uploadPath, posterPath, err => {
        if (err) throw err;

        for (let size of Object.keys(oblecto.config.artwork.poster)) {
          oblecto.queue.pushJob('rescaleImage', {
            from: oblecto.artworkUtils.moviePosterPath(movie),
            to: oblecto.artworkUtils.moviePosterPath(movie, size),
            width: oblecto.config.artwork.poster[size]
          });
        }

        res.send(['success']);
      });
    } catch (e) {
      console.log(e);
      return next(new _restifyErrors.default.Internal('An error has occured during upload of poster'));
    }

    next();
  });
  server.get('/movie/:id/fanart', async function (req, res, next) {
    // Get episode data
    let movie = await _movie.Movie.findByPk(req.params.id, {
      include: [_file.File]
    });
    let fanartPath = oblecto.artworkUtils.movieFanartPath(movie, 'large');

    _fs.default.createReadStream(fanartPath).on('error', () => {
      return next(new _restifyErrors.default.NotFoundError('Fanart for movie does not exist'));
    }).pipe(res);
  });
  server.put('/movie/:id/fanart', _auth.default.requiresAuth, async function (req, res, next) {
    let movie = await _movie.Movie.findByPk(req.params.id, {
      include: [_file.File]
    });

    if (!movie) {
      return next(new _restifyErrors.default.NotFoundError('Movie does not exist'));
    }

    let fanartPath = oblecto.artworkUtils.movieFanartPath(movie);

    if (req.files.length < 1) {
      return next(new _restifyErrors.default.MissingParameter('Image file is missing'));
    }

    let uploadPath = req.files[Object.keys(req.files)[0]].path;

    try {
      let image = await (0, _sharp.default)(uploadPath);
      let metadata = await image.metadata();
      let ratio = metadata.height / metadata.width;

      if (!(1 <= ratio <= 2)) {
        return next(new _restifyErrors.default.InvalidContent('Image aspect ratio is incorrect'));
      }
    } catch (e) {
      return next(new _restifyErrors.default.InvalidContent('File is not an image'));
    }

    try {
      _fs.default.copyFile(uploadPath, fanartPath, err => {
        if (err) throw err;

        for (let size of Object.keys(oblecto.config.artwork.poster)) {
          oblecto.queue.pushJob('rescaleImage', {
            from: oblecto.artworkUtils.movieFanartPath(movie),
            to: oblecto.artworkUtils.movieFanartPath(movie, size),
            width: oblecto.config.artwork.poster[size]
          });
        }

        res.send(['success']);
      });
    } catch (e) {
      console.log(e);
      return next(new _restifyErrors.default.Internal('An error has occured during upload of fanart'));
    }

    next();
  });
  server.get('/movie/:id/info', _auth.default.requiresAuth, async function (req, res) {
    let movie = await _movie.Movie.findByPk(req.params.id, {
      include: [_file.File, {
        model: _trackMovie.TrackMovie,
        required: false,
        where: {
          userId: req.authorization.user.id
        }
      }]
    });
    res.send(movie);
  });
  server.get('/movie/:id/play', async function (req, res, next) {
    let movie = await _movie.Movie.findByPk(req.params.id, {
      include: [{
        model: _file.File
      }]
    });
    let file = movie.files[0];
    res.redirect(`/stream/${file.id}`, next);
  });
  server.get('/movie/:id/sets', _auth.default.requiresAuth, async function (req, res) {
    let sets = await _movie.Movie.findByPk(req.params.id, {
      attributes: [],
      include: [{
        model: _movieSet.MovieSet,
        include: [{
          model: _movie.Movie,
          include: [{
            model: _trackMovie.TrackMovie,
            required: false,
            where: {
              userId: req.authorization.user.id
            }
          }]
        }]
      }]
    });
    res.send(sets.movieSets);
  });
  server.put('/movie/:id/sets', _auth.default.requiresAuth, async function (req, res, next) {
    try {
      let [movie] = await _movie.Movie.findByPk(req.params.id);
      let [set] = await _movieSet.MovieSet.findByPk(req.params.setId);
      set.addMovie(movie);
    } catch (e) {
      return next(new _restifyErrors.default.NotFoundError('Movie or set could not be found'));
    }
  });
  server.get('/movies/search/:name', _auth.default.requiresAuth, async function (req, res) {
    // search for attributes
    let movie = await _movie.Movie.findAll({
      where: {
        movieName: {
          [Op.like]: '%' + req.params.name + '%'
        }
      },
      include: [_file.File]
    });
    res.send(movie);
  });
  server.get('/movies/watching', _auth.default.requiresAuth, async function (req, res) {
    // search for attributes
    let tracks = await _trackMovie.TrackMovie.findAll({
      include: [{
        model: _movie.Movie,
        required: true,
        include: [{
          model: _trackMovie.TrackMovie,
          required: false,
          where: {
            userId: req.authorization.user.id
          }
        }]
      }],
      where: {
        userId: req.authorization.user.id,
        progress: {
          [_sequelize.default.Op.lt]: 0.9
        },
        updatedAt: {
          [_sequelize.default.Op.gt]: new Date() - 1000 * 60 * 60 * 24 * 7
        }
      },
      order: [['updatedAt', 'DESC']]
    }); // We are only interested in the episode objects, so extract all the episode object from
    // each track object and send the final mapped array to the client

    res.send(tracks.map(track => {
      return track.Movie;
    }));
  });
};

exports.default = _default;