"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _restifyErrors = _interopRequireDefault(require("restify-errors"));

var _auth = _interopRequireDefault(require("../middleware/auth"));

var _file = require("../../../models/file");

var _DirectHttpStreamSession = _interopRequireDefault(require("../../../lib/streamSessions/StreamSessionTypes/DirectHttpStreamSession"));

var _HLSStreamer = _interopRequireDefault(require("../../../lib/streamSessions/StreamSessionTypes/HLSStreamer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * @param {Server} server
 * @param {Oblecto} oblecto
 */
var _default = (server, oblecto) => {
  server.get('/HLS/:sessionId/segment/:id', async function (req, res, next) {
    if (!oblecto.streamSessionController.sessionExists(req.params.sessionId)) {
      return next(new _restifyErrors.default.InvalidCredentialsError('Stream session token does not exist'));
    }

    let streamSession = oblecto.streamSessionController.sessions[req.params.sessionId]; // TODO: Send approriate error if session is not a HLS stream session

    if (!(streamSession instanceof _HLSStreamer.default)) return next();
    let segmentId = parseInt(req.params.id);
    await streamSession.streamSegment(req, res, segmentId);
  });
  server.get('/session/create/:id', _auth.default.requiresAuth, async function (req, res, next) {
    let file;

    try {
      file = await _file.File.findByPk(req.params.id);
    } catch (ex) {
      return next(new _restifyErrors.default.NotFoundError('File does not exist'));
    }

    if (!file) return next(new _restifyErrors.default.NotFoundError('File does not exist'));
    let streamType = 'recode';

    if (['recode', 'directhttp', 'hls'].indexOf(req.params.type) > -1) {
      streamType = req.params.type;
    }

    if (req.params.noremux) streamType = 'directhttp';
    let streamSession = oblecto.streamSessionController.newSession(file, {
      streamType,
      target: {
        formats: (req.params.format || 'mp4').split(','),
        videoCodecs: (req.params.videoCodec || 'h264').split(','),
        audioCodecs: (req.params.audioCodec || 'aac').split(',')
      },
      offset: req.params.offset || 0
    });
    res.send({
      sessionId: streamSession.sessionId,
      seeking: streamSession instanceof _DirectHttpStreamSession.default ? 'client' : 'server'
    });
  });
  server.get('/session/stream/:sessionId', async function (req, res, next) {
    if (!oblecto.streamSessionController.sessionExists(req.params.sessionId)) {
      return next(new _restifyErrors.default.InvalidCredentialsError('Stream session token does not exist'));
    }

    return next();
  }, async function (req, res) {
    let streamSession = oblecto.streamSessionController.sessions[req.params.sessionId];

    if (req.params.offset) {
      streamSession.offset = req.params.offset;
    }

    await streamSession.addDestination({
      request: req,
      stream: res,
      type: 'http'
    });
    if (req.params.nostart) return;
    await streamSession.startStream();
  });
};

exports.default = _default;