"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _sequelize = _interopRequireDefault(require("sequelize"));

var _sharp = _interopRequireDefault(require("sharp"));

var _auth = _interopRequireDefault(require("../middleware/auth"));

var _restifyErrors = _interopRequireDefault(require("restify-errors"));

var _series = require("../../../models/series");

var _episode = require("../../../models/episode");

var _trackEpisode = require("../../../models/trackEpisode");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Op = _sequelize.default.Op;

var _default = (server, oblecto) => {
  server.get('/series/list/:sorting', _auth.default.requiresAuth, async function (req, res, next) {
    const limit = parseInt(req.query.count) || 20;
    const page = parseInt(req.query.page) || 0;
    if (!Number.isInteger(limit) || !Number.isInteger(page)) return next(new _restifyErrors.default.BadRequestError('Limit or Page must be a number'));
    let AllowedOrders = ['desc', 'asc'];
    if (AllowedOrders.indexOf(req.query.order.toLowerCase()) === -1) return next(new _restifyErrors.default.BadRequestError('Sorting order is invalid'));
    if (!(req.params.sorting in _series.Series.rawAttributes)) return next(new _restifyErrors.default.BadRequestError('Sorting method is invalid'));
    let results = await _series.Series.findAll({
      order: [[req.params.sorting, req.query.order]],
      limit,
      offset: limit * page
    });
    res.send(results);
  });
  server.get('/series/:id/info', _auth.default.requiresAuth, async function (req, res) {
    let show = await _series.Series.findByPk(req.params.id);
    if (show.genre) show.genre = JSON.parse(show.genre);
    res.send(show);
  }); // Endpoint to get all episodes within a series

  server.get('/series/:id/episodes', _auth.default.requiresAuth, async function (req, res) {
    let show = await _episode.Episode.findAll({
      include: [_series.Series, {
        model: _trackEpisode.TrackEpisode,
        required: false,
        where: {
          userId: req.authorization.user.id
        }
      }],
      where: {
        SeriesId: req.params.id
      },
      order: [['airedSeason', 'ASC'], ['airedEpisodeNumber', 'ASC']]
    });
    res.send(show);
  });
  server.get('/series/:id/poster', async function (req, res, next) {
    let show;

    try {
      show = await _series.Series.findByPk(req.params.id);
    } catch (e) {
      return next(new _restifyErrors.default.NotFoundError('Series does not exist'));
    }

    let imagePath = oblecto.artworkUtils.seriesPosterPath(show, req.params.size || 'medium');

    _fs.default.createReadStream(imagePath).on('error', () => {
      return next(new _restifyErrors.default.NotFoundError('No poster found'));
    }).pipe(res);
  });
  server.put('/series/:id/poster', _auth.default.requiresAuth, async function (req, res, next) {
    let show = await _series.Series.findByPk(req.params.id);

    if (!show) {
      return next(new _restifyErrors.default.NotFoundError('Movie does not exist'));
    }

    let posterPath = _path.default.normalize(oblecto.config.assets.showPosterLocation) + '/' + show.id + '.jpg';

    if (oblecto.config.assets.storeWithFile) {
      let showPath = show.directory;
      posterPath = _path.default.join(showPath, show.seriesName + '-poster.jpg');
    }

    if (req.files.length < 1) {
      return next(new _restifyErrors.default.MissingParameterError('Image file is missing'));
    }

    let uploadPath = req.files[Object.keys(req.files)[0]].path;

    try {
      let image = await (0, _sharp.default)(uploadPath);
      let metadata = await image.metadata();
      let ratio = metadata.height / metadata.width;

      if (!(1 <= ratio <= 2)) {
        return next(new _restifyErrors.default.InvalidContentError('Image aspect ratio is incorrect'));
      }
    } catch (e) {
      return next(new _restifyErrors.default.InvalidContentError('File is not an image'));
    }

    try {
      _fs.default.copyFile(uploadPath, posterPath, err => {
        if (err) throw err;
        res.send(['success']);
      });
    } catch (e) {
      return next(new _restifyErrors.default.InternalError('An error has occurred during upload of poster'));
    }

    next();
  });
  server.get('/shows/search/:name', _auth.default.requiresAuth, async function (req, res) {
    let series = await _series.Series.findAll({
      where: {
        seriesName: {
          [Op.like]: '%' + req.params.name + '%'
        }
      }
    });
    res.send(series);
  });
};

exports.default = _default;