"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _restifyErrors = _interopRequireDefault(require("restify-errors"));

var _bcrypt = _interopRequireDefault(require("bcrypt"));

var _config = _interopRequireDefault(require("../../../config"));

var _auth = _interopRequireDefault(require("../middleware/auth"));

var _user = require("../../../models/user");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = (server, oblecto) => {
  server.get('/users', async function (req, res, next) {
    let users = await _user.User.findAll({
      attributes: ['username', 'name', 'email', 'id']
    });
    res.send(users);
    next();
  });
  server.get('/user/:id', _auth.default.requiresAuth, async function (req, res, next) {
    let user = await _user.User.findOne({
      where: {
        id: req.params.id
      },
      attributes: ['username', 'name', 'email', 'id']
    });
    res.send(user);
    next();
  });
  server.del('/user/:id', _auth.default.requiresAuth, async function (req, res, next) {
    let user = await _user.User.findOne({
      where: {
        id: req.params.id
      },
      attributes: ['username', 'name', 'email', 'id']
    }); // Send the user information of the user to the client first

    res.send(user); // Now delete the user

    user.destroy();
    next();
  }); // Endpoint to update the entries of a certain user

  server.put('/user/:id', _auth.default.requiresAuth, async function (req, res, next) {
    let user = await _user.User.findByPk(req.params.id);

    if (!user) {
      return next(new _restifyErrors.default.BadRequestError('User with id does not exist'));
    }

    if (req.params.username) {
      user.update({
        username: req.params.username
      });
    }

    if (req.params.password) {
      user.update({
        password: await _bcrypt.default.hash(req.params.password, _config.default.authentication.saltRounds)
      });
    }

    if (req.params.email) {
      user.update({
        email: req.params.email
      });
    }

    if (req.params.name) {
      user.update({
        name: req.params.name
      });
    }

    next();
  });
  server.post('/user', _auth.default.requiresAuth, async function (req, res, next) {
    // Make sure the required input fields are present, and if not send a bad request error with the associated information to the error
    if (!req.params.username) return next(new _restifyErrors.default.BadRequestError('Username is missing'));
    if (!req.params.email) return next(new _restifyErrors.default.BadRequestError('E-Mail is missing'));
    if (!req.params.name) return next(new _restifyErrors.default.BadRequestError('Name is missing'));
    let passwordHash;
    if (req.params.password) passwordHash = await _bcrypt.default.hash(req.params.password, oblecto.config.authentication.saltRounds);
    let [user] = await _user.User.findOrCreate({
      where: {
        username: req.params.username
      },
      defaults: {
        name: req.params.name,
        email: req.params.email,
        password: passwordHash
      }
    });
    res.send(user);
    next();
  });
};

exports.default = _default;