"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initDatabase = initDatabase;

var _sequelize = _interopRequireDefault(require("sequelize"));

var _config = _interopRequireDefault(require("../config.js"));

var _logger = _interopRequireDefault(require("./logger"));

var _episode = require("../models/episode");

var _episodeFiles = require("../models/episodeFiles");

var _file = require("../models/file");

var _movie = require("../models/movie");

var _series = require("../models/series");

var _movieFiles = require("../models/movieFiles");

var _movieSet = require("../models/movieSet");

var _seriesSet = require("../models/seriesSet");

var _trackMovie = require("../models/trackMovie");

var _trackEpisode = require("../models/trackEpisode");

var _user = require("../models/user");

var _stream = require("../models/stream");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function initDatabase() {
  let dialect = _config.default.database.dialect || 'sqlite';
  let poolmax = _config.default.queue.concurrency;

  if (dialect === 'sqlite') {
    _logger.default.log('INFO', 'Using SQLITE, setting poolmax to 1');

    poolmax = 1;
  }

  let options = {
    dialect,
    logging: false,
    //operatorsAliases: false,
    pool: {
      max: poolmax,
      min: 0,
      acquire: 30000,
      idle: 10000
    },
    retry: {
      max: 5
    }
  };

  if (options.dialect !== 'sqlite') {
    options.host = _config.default.database.host || 'localhost';
  }

  if (options.dialect === 'sqlite') {
    options.storage = _config.default.database.storage || '/etc/oblecto/database.sqlite';
  }

  const sequelize = new _sequelize.default(_config.default.database.database, _config.default.database.username, _config.default.database.password, options);

  _episode.Episode.init(_episode.episodeColumns, {
    sequelize
  });

  _movie.Movie.init(_movie.movieColumns, {
    sequelize
  });

  _series.Series.init(_series.seriesColumns, {
    sequelize
  });

  _file.File.init(_file.fileColumns, {
    sequelize
  });

  _stream.Stream.init(_stream.streamColumns, {
    sequelize
  });

  _episodeFiles.EpisodeFiles.init(_episodeFiles.episodeFilesColumns, {
    sequelize
  });

  _movieFiles.MovieFiles.init(_movieFiles.movieFileColumns, {
    sequelize
  });

  _movieSet.MovieSet.init(_movieSet.movieSetColumns, {
    sequelize
  });

  _seriesSet.SeriesSet.init(_seriesSet.seriesSetColumns, {
    sequelize
  });

  _trackMovie.TrackMovie.init(_trackMovie.trackMovieColumns, {
    sequelize
  });

  _trackEpisode.TrackEpisode.init(_trackEpisode.trackEpisodesColumns, {
    sequelize
  });

  _user.User.init(_user.userColumns, {
    sequelize
  });

  _episode.Episode.belongsTo(_series.Series);

  _series.Series.hasMany(_episode.Episode);

  _movieSet.MovieSet.belongsToMany(_movie.Movie, {
    through: 'MovieSetAllocations'
  });

  _movieSet.MovieSet.belongsToMany(_user.User, {
    through: 'MovieSetUsers'
  });

  _movie.Movie.belongsToMany(_movieSet.MovieSet, {
    through: 'MovieSetAllocations'
  });

  _seriesSet.SeriesSet.belongsToMany(_series.Series, {
    through: 'SeriesSetAllocations'
  });

  _series.Series.belongsToMany(_seriesSet.SeriesSet, {
    through: 'SeriesSetAllocations'
  });

  _episode.Episode.belongsToMany(_file.File, {
    through: _episodeFiles.EpisodeFiles
  });

  _movie.Movie.belongsToMany(_file.File, {
    through: _movieFiles.MovieFiles
  });

  _file.File.belongsToMany(_episode.Episode, {
    through: _episodeFiles.EpisodeFiles
  });

  _file.File.belongsToMany(_movie.Movie, {
    through: _movieFiles.MovieFiles
  });

  _stream.Stream.belongsTo(_file.File);

  _file.File.hasMany(_stream.Stream);

  _trackEpisode.TrackEpisode.belongsTo(_user.User);

  _trackEpisode.TrackEpisode.belongsTo(_episode.Episode);

  _trackMovie.TrackMovie.belongsTo(_user.User);

  _trackMovie.TrackMovie.belongsTo(_movie.Movie);

  _episode.Episode.hasMany(_trackEpisode.TrackEpisode);

  _movie.Movie.hasMany(_trackMovie.TrackMovie);

  return sequelize;
}